diff src/util.h @ 7261:1930e3d00ecd

[gaim-migrate @ 7838] prpl-specific normalize is back, after my crusade to kill it. committer: Tailor Script <tailor@pidgin.im>
author Nathan Walp <nwalp@pidgin.im>
date Tue, 14 Oct 2003 05:07:39 +0000
parents d14e026611c0
children 3ec38f08b0b2
line wrap: on
line diff
--- a/src/util.h	Tue Oct 14 04:44:43 2003 +0000
+++ b/src/util.h	Tue Oct 14 05:07:39 2003 +0000
@@ -302,11 +302,12 @@
  * g_strdup() it. Also, calling normalize() twice in the same line
  * will lead to problems.
  *
  * @param str The string to normalize.
  *
  * @return A pointer to the normalized version stored in a static buffer.
  */
-const char *gaim_normalize(const char *str);
+const char *gaim_normalize(const GaimAccount *account, const char *str);
 
 /**
  * Looks for %n, %d, or %t in a string, and replaces them with the
@@ -302,11 +302,12 @@
  * will lead to problems.
  *
- * @param str The string to normalize.
+ * @param account  The account the string belongs to.
+ * @param str      The string to normalize.
  *
  * @return A pointer to the normalized version stored in a static buffer.